@@ -13,13 +13,20 @@ class AlprBase(Base):
     def __init__(self, logger=None,options={}, tempdir='/tmp'):
         super().__init__(logger)
         if not options.get('alpr_key'):
-            self.logger.Debug (1,'No API key specified, hopefully you do not need one')
+            self.logger.Debug (2,'No API key specified, hopefully you do not need one')
         self.apikey = options.get('alpr_key')
-        #print (self.apikey)
         self.tempdir = tempdir
         self.url = options.get('alpr_url')
         self.options = options
-        
+    
+    def acquire_lock(self):
+        pass
+
+    def release_lock(self):
+        pass
+
+    def load_model(self):
+        pass
 
     def setkey(self, key=None):
         self.apikey = key
@@ -28,7 +35,7 @@ class AlprBase(Base):
     def stats(self):
         self.logger.Debug(1,'stats not implemented in base class')
 
-    def detect(self, object):
+    def detect(self, image=None):
         self.logger.Debug(1,'detect not implemented in base class')
 
     def prepare(self, object):
@@ -49,7 +56,7 @@ class AlprBase(Base):
             # If it is a file and zm_detect sent it, it would already be resized
             # If it is a file and zm_detect did not send it, no need to adjust scales
             # as there won't be a yolo/alpr size mismatch
-            self.logger.Debug(1,f'supplied object is a file {object}')
+            self.logger.Debug(2,f'supplied object is a file {object}')
             self.filename = object
            
             self.remove_temp = False
@@ -98,8 +105,8 @@ class Alpr(AlprBase):
         else:
             raise ValueError('ALPR service "{}" not known'.format(self.options.get('alpr_service')))
 
-    def detect(self, object):
-        return self.alpr_obj.detect(object)
+    def detect(self, image=None):
+        return self.alpr_obj.detect(image)
 
     def stats(self):
         return self.alpr_obj.stats()
@@ -153,7 +160,7 @@ class PlateRecognizer(AlprBase):
             response = response.json()
         return response
 
-    def detect(self, object):
+    def detect(self, image=None):
         """Detects license plate using platerecognizer
 
         Args:
@@ -161,13 +168,14 @@ class PlateRecognizer(AlprBase):
 
         Returns:
             boxes, labels, confidences: 3 objects, containing bounding boxes, labels and confidences
-        """        
+        """    
+        object = image    
         bbox = []
         labels = []
         confs = []
         self.prepare(object)
         if self.options.get('platerec_stats') == 'yes':
-            self.logger.Debug(1,'Plate Recognizer API usage stats: {}'.format(
+            self.logger.Debug(2,'Plate Recognizer API usage stats: {}'.format(
                 json.dumps(self.stats())))
         with open(self.filename, 'rb') as fp:
             try:
@@ -177,6 +185,8 @@ class PlateRecognizer(AlprBase):
                 payload = self.options.get('platerec_regions')
                 response = requests.post(
                    platerec_url,
+                   timeout=15,
+
                     #self.url ,
                     files=dict(upload=fp),
                     data=payload,
@@ -193,7 +203,7 @@ class PlateRecognizer(AlprBase):
                 )
             else:
                 response = response.json()
-                self.logger.Debug(2,'ALPR JSON: {}'.format(response))
+                self.logger.Debug(3,'ALPR JSON: {}'.format(response))
 
         #(xfactor, yfactor) = self.getscale()
 
@@ -211,7 +221,7 @@ class PlateRecognizer(AlprBase):
                     y1 = round(int(plates['box']['ymin']))
                     x2 = round(int(plates['box']['xmax']))
                     y2 = round(int(plates['box']['ymax']))
-                    labels.append(label)
+                    labels.append('alpr:{}'.format(label))
                     bbox.append([x1, y1, x2, y2])
                     confs.append(plates['score'])
                 else:
@@ -241,7 +251,7 @@ class OpenAlpr(AlprBase):
             format(self.url))
         
 
-    def detect(self, object):
+    def detect(self, image=None):
         """Detection using OpenALPR
 
         Args:
@@ -249,7 +259,8 @@ class OpenAlpr(AlprBase):
 
         Returns:
             boxes, labels, confidences: 3 objects, containing bounding boxes, labels and confidences
-        """        
+        """  
+        object = image      
         bbox = []
         labels = []
         confs = []
@@ -270,7 +281,7 @@ class OpenAlpr(AlprBase):
 
                 rurl = '{}?secret_key={}{}'.format(self.url, self.apikey,
                                                    params)
-                self.logger.Debug(1,'Trying OpenALPR with url:' + rurl)
+                self.logger.Debug(2,'Trying OpenALPR with url:' + rurl)
                 response = requests.post(rurl, files={'image': fp})
                 response.raise_for_status()
             except requests.exceptions.RequestException as e:
@@ -284,7 +295,7 @@ class OpenAlpr(AlprBase):
                 )
             else:
                 response = response.json()
-                self.logger.Debug(1,'OpenALPR JSON: {}'.format(response))
+                self.logger.Debug(2,'OpenALPR JSON: {}'.format(response))
 
         #(xfactor, yfactor) = self.getscale()
 
@@ -314,7 +325,7 @@ class OpenAlpr(AlprBase):
                 y1 = round(int(plates['coordinates'][0]['y']))
                 x2 = round(int(plates['coordinates'][2]['x']))
                 y2 = round(int(plates['coordinates'][2]['y']))
-                labels.append(label)
+                labels.append('alpr:{}'.format(label))
                 bbox.append([x1, y1, x2, y2])
                 confs.append(conf)
 
@@ -340,7 +351,7 @@ class OpenAlprCmdLine(AlprBase):
             self.cmd = self.cmd + ' -j'
       
 
-    def detect(self, object):
+    def detect(self, image = None):
         """Detection using OpenALPR command line
 
         Args:
@@ -348,16 +359,17 @@ class OpenAlprCmdLine(AlprBase):
 
          Returns:
             boxes, labels, confidences: 3 objects, containing bounding boxes, labels and confidences
-        """             
+        """ 
+        object = image            
         bbox = []
         labels = []
         confs = []
 
         self.prepare(object)
         self.cmd = self.cmd + ' ' + self.filename
-        self.logger.Debug (1,'OpenALPR CmdLine Executing: {}'.format(self.cmd))
+        self.logger.Debug (2,'OpenALPR CmdLine Executing: {}'.format(self.cmd))
         response = subprocess.check_output(self.cmd, shell=True)      
-        self.logger.Debug (1,'OpenALPR CmdLine Response: {}'.format(response))
+        self.logger.Debug (2,'OpenALPR CmdLine Response: {}'.format(response))
         try:
             response = json.loads(response)
         except ValueError as e:
@@ -385,7 +397,7 @@ class OpenAlprCmdLine(AlprBase):
                 y1 = round(int(plates['coordinates'][0]['y']))
                 x2 = round(int(plates['coordinates'][2]['x']))
                 y2 = round(int(plates['coordinates'][2]['y']))
-                labels.append(label)
+                labels.append('alpr:{}'.format(label))
                 bbox.append([x1, y1, x2, y2])
                 confs.append(conf)
 
